@@ -1,9 +1,9 @@
 # -*- coding:utf-8 -*-
 # @文件名  :__init__.py
 # @时间    :2022/12/1 23:45
-# @作者    :jie
+# @作者    :Zed
 # @目的
-from .matrix import Series, DataFrame, Matrix
+from matrix_last import Series, DataFrame, Matrix
 
 
 
